Welcome to CliMT's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

   introduction
   installation
   quickstart
   interaction
   realistic
   component_types
   configuration
   components
   initialisation
   utilities
   contributing
   authors
   history

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
